@@ -20,7 +20,7 @@
 
 #include "ma_fulltext.h"
 #include <my_check_opt.h>
-#if defined(MSDOS) || defined(__WIN__)
+#if defined(_WIN32)
 #include <fcntl.h>
 #else
 #include <stddef.h>
@@ -30,13 +30,11 @@
 /* static variables */
 
 #undef MIN_SORT_MEMORY
-#undef MYF_RW
 #undef DISK_BUFFER_SIZE
 
 #define MERGEBUFF 15
 #define MERGEBUFF2 31
 #define MIN_SORT_MEMORY (4096-MALLOC_OVERHEAD)
-#define MYF_RW  MYF(MY_NABP | MY_WME | MY_WAIT_IF_FULL)
 #define DISK_BUFFER_SIZE (IO_SIZE*128)
 
 /* How many keys we can keep in memory */
@@ -196,12 +194,12 @@ int _ma_create_index_by_sort(MARIA_SORT_PARAM *info, my_bool no_messages,
     }
 
     if ((sort_keys= ((uchar**)
-                     my_malloc((size_t) (keys*(sort_length+sizeof(char*))+
+                     my_malloc(PSI_INSTRUMENT_ME, (size_t) (keys*(sort_length+sizeof(char*))+
                                          HA_FT_MAXBYTELEN),
                                MYF(0)))))
     {
-      if (my_init_dynamic_array(&buffpek, sizeof(BUFFPEK), maxbuffer,
-                                MY_MIN(maxbuffer/2, 1000), MYF(0)))
+      if (my_init_dynamic_array(PSI_INSTRUMENT_ME, &buffpek, sizeof(BUFFPEK),
+                                maxbuffer, MY_MIN(maxbuffer/2, 1000), MYF(0)))
       {
 	my_free(sort_keys);
         sort_keys= 0;
@@ -430,11 +428,11 @@ static my_bool _ma_thr_find_all_keys_exec(MARIA_SORT_PARAM* sort_param)
       while ((maxbuffer= (uint) (idx/(keys-1)+1)) != maxbuffer_org);
     }
     if ((sort_keys= (uchar **)
-         my_malloc((size_t)(keys*(sort_length+sizeof(char*))+
+         my_malloc(PSI_INSTRUMENT_ME, (size_t)(keys*(sort_length+sizeof(char*))+
                    ((sort_param->keyinfo->flag & HA_FULLTEXT) ?
                     HA_FT_MAXBYTELEN : 0)), MYF(0))))
     {
-      if (my_init_dynamic_array(&sort_param->buffpek, sizeof(BUFFPEK),
+      if (my_init_dynamic_array(PSI_INSTRUMENT_ME, &sort_param->buffpek, sizeof(BUFFPEK),
                              maxbuffer, MY_MIN(maxbuffer / 2, 1000), MYF(0)))
       {
         my_free(sort_keys);
@@ -630,7 +628,7 @@ int _ma_thr_write_keys(MARIA_SORT_PARAM *sort_param)
         length=(size_t)param->sort_buffer_length;
         while (length >= MIN_SORT_MEMORY)
         {
-          if ((mergebuf= my_malloc((size_t) length, MYF(0))))
+          if ((mergebuf= my_malloc(PSI_INSTRUMENT_ME, (size_t) length, MYF(0))))
               break;
           length=length*3/4;
         }
